package Locale::CLDR::Transformations::Any::Bopomofo::Latin;
# This file auto generated from Data\common\transforms\Latin-Bopomofo.xml
#	on Sat 24 Oct  9:19:23 am GMT

use version;

our $VERSION = version->declare('v0.28.1');

use v5.10.1;
use mro 'c3';
use utf8;
use if $^V ge v5.12.0, feature => 'unicode_strings';

use Moose;

BEGIN {
	die "Transliteration requires Perl 5.18 or above"
		unless $^V ge v5.18.0;
}

no warnings 'experimental::regex_sets';
has 'transforms' => (
	is => 'ro',
	isa => 'ArrayRef',
	init_arg => undef,
	default => sub { [
		qr/(?^um:\G.)/,
		{
			type => 'transform',
			data => [
			],
		},
		{
			type => 'conversion',
			data => [
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:˙)),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:zhuyin˙)),
					result  => q(#tone5(light):pinyintypicallyunmarkedoruse5),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ˋ)),
					result  => q(4),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ˇ)),
					result  => q(3),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ˊ)),
					result  => q(2),
					revisit => 0,
				},
				{
					before  => q((?^u:(?[[ㄅ-ㄩ] - [ㄅ ㄆ ㄈ ㄉ ㄊ ㄌ ㄍ ㄎ ㄏ ㄐ ㄑ ㄒ]]))),
					after   => q(),
					replace => q((?^u:ˋ)),
					result  => q(4),
					revisit => 0,
				},
				{
					before  => q((?^u:(?[[ㄅ-ㄩ] - [ㄅ ㄆ ㄈ ㄉ ㄊ ㄌ ㄍ ㄎ ㄏ ㄐ ㄑ ㄒ]]))),
					after   => q(),
					replace => q((?^u:ˇ)),
					result  => q(3),
					revisit => 0,
				},
				{
					before  => q((?^u:(?[[ㄅ-ㄩ] - [ㄅ ㄆ ㄈ ㄉ ㄊ ㄌ ㄍ ㄎ ㄏ ㄐ ㄑ ㄒ]]))),
					after   => q(),
					replace => q((?^u:ˊ)),
					result  => q(2),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(#1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ˉ)),
					result  => q(1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:zhuyintypicallyunmarkedoruseˉ)),
					result  => q(#tone1:pinyinu0304or1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄒ)),
					result  => q(x),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄑ)),
					result  => q(q),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄐ)),
					result  => q(j),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄏ)),
					result  => q(h),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄎ)),
					result  => q(k),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄍ)),
					result  => q(g),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄌ)),
					result  => q(l),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄋ)),
					result  => q(#n),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄊ)),
					result  => q(t),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄉ)),
					result  => q(d),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄈ)),
					result  => q(f),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄇ)),
					result  => q(#m),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄆ)),
					result  => q(p),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄅ)),
					result  => q(b),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(#iong),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(#ong),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(#uang),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(#ui),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(#uai),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(#uo),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(#ua),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(#ing),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(#iang),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(#in),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(#ian),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(#iu),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(#iao),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(#ie),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(#ia),
					revisit => 0,
				},
				{
					before  => q((?^u:[ㄅ-ㄙ])),
					after   => q(),
					replace => q(),
					result  => q(#ia1),
					revisit => 0,
				},
				{
					before  => q((?^u:[ㄅ-ㄙ])),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄧㄚ)),
					result  => q(ia),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄋ)),
					result  => q(n1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄋ)),
					result  => q(n),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄇ)),
					result  => q(m1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄇ)),
					result  => q(m),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄜ)),
					result  => q(e1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄜ)),
					result  => q(e),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄛ)),
					result  => q(o1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄛ)),
					result  => q(o),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄚ)),
					result  => q(a1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄚ)),
					result  => q(a),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄦ)),
					result  => q(er1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄦ)),
					result  => q(er),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄣ)),
					result  => q(en1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄣ)),
					result  => q(en),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄢ)),
					result  => q(an1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄢ)),
					result  => q(an),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄡ)),
					result  => q(ou1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄡ)),
					result  => q(ou),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄠ)),
					result  => q(ao1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄠ)),
					result  => q(ao),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄟ)),
					result  => q(ei1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄟ)),
					result  => q(ei),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄞ)),
					result  => q(ai1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄞ)),
					result  => q(ai),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄝ)),
					result  => q(eh1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄝ)),
					result  => q(eh),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄥ)),
					result  => q(eng1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄥ)),
					result  => q(eng),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄤ)),
					result  => q(ang1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄤ)),
					result  => q(ang),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄨ)),
					result  => q(wu1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄨ)),
					result  => q(wu),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄨㄛ)),
					result  => q(wo1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄨㄛ)),
					result  => q(wo),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄨㄚ)),
					result  => q(wa1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄨㄚ)),
					result  => q(wa),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄨㄣ)),
					result  => q(wen1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄨㄣ)),
					result  => q(wen),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄨㄢ)),
					result  => q(wan1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄨㄢ)),
					result  => q(wan),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄨㄟ)),
					result  => q(wei1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄨㄟ)),
					result  => q(wei),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄨㄞ)),
					result  => q(wai1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄨㄞ)),
					result  => q(wai),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄨㄥ)),
					result  => q(weng1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄨㄥ)),
					result  => q(weng),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄨㄤ)),
					result  => q(wang1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄨㄤ)),
					result  => q(wang),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄨㄨㄥ)),
					result  => q(wong1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄨㄨㄥ)),
					result  => q(wong),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄧ)),
					result  => q(yi1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄧ)),
					result  => q(yi),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄧㄝ)),
					result  => q(ye1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄧㄝ)),
					result  => q(ye),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄧㄛ)),
					result  => q(yo1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄧㄛ)),
					result  => q(yo),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄧㄚ)),
					result  => q(ya1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄧㄚ)),
					result  => q(ya),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄧㄣ)),
					result  => q(yin1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄧㄣ)),
					result  => q(yin),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄧㄢ)),
					result  => q(yan1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄧㄢ)),
					result  => q(yan),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄧㄡ)),
					result  => q(you1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄧㄡ)),
					result  => q(you),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄧㄠ)),
					result  => q(yao1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄧㄠ)),
					result  => q(yao),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄧㄞ)),
					result  => q(yai1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄧㄞ)),
					result  => q(yai),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄧㄥ)),
					result  => q(ying1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄧㄥ)),
					result  => q(ying),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄧㄤ)),
					result  => q(yang1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄧㄤ)),
					result  => q(yang),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄩ)),
					result  => q(yu1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄩ)),
					result  => q(yu),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄩㄣ)),
					result  => q(yun1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄩㄣ)),
					result  => q(yun),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄩㄝ)),
					result  => q(yue1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄩㄝ)),
					result  => q(yue),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄩㄥ)),
					result  => q(yong1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄩㄥ)),
					result  => q(yong),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄩㄢ)),
					result  => q(yuan1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄩㄢ)),
					result  => q(yuan),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄙ)),
					result  => q(si1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄙ)),
					result  => q(si),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄙㄨ)),
					result  => q(su1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄙㄨ)),
					result  => q(su),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄙㄜ)),
					result  => q(se1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄙㄜ)),
					result  => q(se),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄙㄚ)),
					result  => q(sa1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄙㄚ)),
					result  => q(sa),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄙㄨㄣ)),
					result  => q(sun1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄙㄨㄣ)),
					result  => q(sun),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄙㄨㄟ)),
					result  => q(sui1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄙㄨㄟ)),
					result  => q(sui),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄙㄨㄛ)),
					result  => q(suo1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄙㄨㄛ)),
					result  => q(suo),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄙㄣ)),
					result  => q(sen1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄙㄣ)),
					result  => q(sen),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄙㄢ)),
					result  => q(san1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄙㄢ)),
					result  => q(san),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄙㄡ)),
					result  => q(sou1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄙㄡ)),
					result  => q(sou),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄙㄠ)),
					result  => q(sao1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄙㄠ)),
					result  => q(sao),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄙㄟ)),
					result  => q(sei1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄙㄟ)),
					result  => q(sei),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄙㄞ)),
					result  => q(sai1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄙㄞ)),
					result  => q(sai),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄙㄨㄥ)),
					result  => q(song1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄙㄨㄥ)),
					result  => q(song),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄙㄨㄢ)),
					result  => q(suan1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄙㄨㄢ)),
					result  => q(suan),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄙㄥ)),
					result  => q(seng1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄙㄥ)),
					result  => q(seng),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄙㄤ)),
					result  => q(sang1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄙㄤ)),
					result  => q(sang),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄘ)),
					result  => q(ci1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄘ)),
					result  => q(ci),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄘㄨ)),
					result  => q(cu1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄘㄨ)),
					result  => q(cu),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄘㄜ)),
					result  => q(ce1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄘㄜ)),
					result  => q(ce),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄘㄚ)),
					result  => q(ca1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄘㄚ)),
					result  => q(ca),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄘㄨㄣ)),
					result  => q(cun1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄘㄨㄣ)),
					result  => q(cun),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄘㄨㄟ)),
					result  => q(cui1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄘㄨㄟ)),
					result  => q(cui),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄘㄨㄛ)),
					result  => q(cuo1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄘㄨㄛ)),
					result  => q(cuo),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄘㄣ)),
					result  => q(cen1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄘㄣ)),
					result  => q(cen),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄘㄢ)),
					result  => q(can1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄘㄢ)),
					result  => q(can),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄘㄡ)),
					result  => q(cou1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄘㄡ)),
					result  => q(cou),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄘㄠ)),
					result  => q(cao1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄘㄠ)),
					result  => q(cao),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄘㄞ)),
					result  => q(cai1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄘㄞ)),
					result  => q(cai),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄘㄨㄥ)),
					result  => q(cong1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄘㄨㄥ)),
					result  => q(cong),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄘㄨㄢ)),
					result  => q(cuan1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄘㄨㄢ)),
					result  => q(cuan),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄘㄥ)),
					result  => q(ceng1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄘㄥ)),
					result  => q(ceng),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄘㄤ)),
					result  => q(cang1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄘㄤ)),
					result  => q(cang),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄗ)),
					result  => q(zi1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄗ)),
					result  => q(zi),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄗㄨ)),
					result  => q(zu1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄗㄨ)),
					result  => q(zu),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄗㄜ)),
					result  => q(ze1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄗㄜ)),
					result  => q(ze),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄗㄚ)),
					result  => q(za1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄗㄚ)),
					result  => q(za),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄗㄨㄣ)),
					result  => q(zun1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄗㄨㄣ)),
					result  => q(zun),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄗㄨㄟ)),
					result  => q(zui1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄗㄨㄟ)),
					result  => q(zui),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄗㄨㄛ)),
					result  => q(zuo1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄗㄨㄛ)),
					result  => q(zuo),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄗㄣ)),
					result  => q(zen1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄗㄣ)),
					result  => q(zen),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄗㄢ)),
					result  => q(zan1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄗㄢ)),
					result  => q(zan),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄗㄡ)),
					result  => q(zou1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄗㄡ)),
					result  => q(zou),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄗㄠ)),
					result  => q(zao1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄗㄠ)),
					result  => q(zao),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄗㄟ)),
					result  => q(zei1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄗㄟ)),
					result  => q(zei),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄗㄞ)),
					result  => q(zai1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄗㄞ)),
					result  => q(zai),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄗㄨㄥ)),
					result  => q(zong1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄗㄨㄥ)),
					result  => q(zong),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄗㄨㄢ)),
					result  => q(zuan1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄗㄨㄢ)),
					result  => q(zuan),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄗㄥ)),
					result  => q(zeng1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄗㄥ)),
					result  => q(zeng),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄗㄤ)),
					result  => q(zang1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄗㄤ)),
					result  => q(zang),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄖ)),
					result  => q(ri1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄖ)),
					result  => q(ri),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄖㄨ)),
					result  => q(ru1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄖㄨ)),
					result  => q(ru),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄖㄜ)),
					result  => q(re1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄖㄜ)),
					result  => q(re),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄖㄚ)),
					result  => q(ra1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄖㄚ)),
					result  => q(ra),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄖㄨㄣ)),
					result  => q(run1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄖㄨㄣ)),
					result  => q(run),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄖㄨㄟ)),
					result  => q(rui1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄖㄨㄟ)),
					result  => q(rui),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄖㄨㄛ)),
					result  => q(ruo1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄖㄨㄛ)),
					result  => q(ruo),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄖㄣ)),
					result  => q(ren1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄖㄣ)),
					result  => q(ren),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄖㄢ)),
					result  => q(ran1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄖㄢ)),
					result  => q(ran),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄖㄡ)),
					result  => q(rou1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄖㄡ)),
					result  => q(rou),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄖㄠ)),
					result  => q(rao1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄖㄠ)),
					result  => q(rao),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄖㄨㄥ)),
					result  => q(rong1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄖㄨㄥ)),
					result  => q(rong),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄖㄨㄢ)),
					result  => q(ruan1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄖㄨㄢ)),
					result  => q(ruan),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄖㄥ)),
					result  => q(reng1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄖㄥ)),
					result  => q(reng),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄖㄤ)),
					result  => q(rang1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄖㄤ)),
					result  => q(rang),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄕ)),
					result  => q(shi1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄕ)),
					result  => q(shi),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄕㄨ)),
					result  => q(shu1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄕㄨ)),
					result  => q(shu),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄕㄜ)),
					result  => q(she1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄕㄜ)),
					result  => q(she),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄕㄚ)),
					result  => q(sha1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄕㄚ)),
					result  => q(sha),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄕㄨㄣ)),
					result  => q(shun1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄕㄨㄣ)),
					result  => q(shun),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄕㄨㄟ)),
					result  => q(shui1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄕㄨㄟ)),
					result  => q(shui),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄕㄨㄛ)),
					result  => q(shuo1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄕㄨㄛ)),
					result  => q(shuo),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄕㄨㄚ)),
					result  => q(shua1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄕㄨㄚ)),
					result  => q(shua),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄕㄣ)),
					result  => q(shen1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄕㄣ)),
					result  => q(shen),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄕㄢ)),
					result  => q(shan1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄕㄢ)),
					result  => q(shan),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄕㄡ)),
					result  => q(shou1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄕㄡ)),
					result  => q(shou),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄕㄠ)),
					result  => q(shao1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄕㄠ)),
					result  => q(shao),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄕㄟ)),
					result  => q(shei1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄕㄟ)),
					result  => q(shei),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄕㄞ)),
					result  => q(shai1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄕㄞ)),
					result  => q(shai),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄕㄨㄢ)),
					result  => q(shuan1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄕㄨㄢ)),
					result  => q(shuan),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄕㄨㄞ)),
					result  => q(shuai1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄕㄨㄞ)),
					result  => q(shuai),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄕㄥ)),
					result  => q(sheng1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄕㄥ)),
					result  => q(sheng),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄕㄤ)),
					result  => q(shang1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄕㄤ)),
					result  => q(shang),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄕㄡㄥ)),
					result  => q(shong1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄕㄡㄥ)),
					result  => q(shong),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄕㄨㄤ)),
					result  => q(shuang1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄕㄨㄤ)),
					result  => q(shuang),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄔ)),
					result  => q(chi1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄔ)),
					result  => q(chi),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄔㄨ)),
					result  => q(chu1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄔㄨ)),
					result  => q(chu),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄔㄜ)),
					result  => q(che1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄔㄜ)),
					result  => q(che),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄔㄚ)),
					result  => q(cha1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄔㄚ)),
					result  => q(cha),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄔㄨㄣ)),
					result  => q(chun1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄔㄨㄣ)),
					result  => q(chun),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄔㄨㄟ)),
					result  => q(chui1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄔㄨㄟ)),
					result  => q(chui),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄔㄨㄛ)),
					result  => q(chuo1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄔㄨㄛ)),
					result  => q(chuo),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄔㄨㄚ)),
					result  => q(chua1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄔㄨㄚ)),
					result  => q(chua),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄔㄣ)),
					result  => q(chen1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄔㄣ)),
					result  => q(chen),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄔㄢ)),
					result  => q(chan1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄔㄢ)),
					result  => q(chan),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄔㄡ)),
					result  => q(chou1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄔㄡ)),
					result  => q(chou),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄔㄠ)),
					result  => q(chao1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄔㄠ)),
					result  => q(chao),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄔㄞ)),
					result  => q(chai1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄔㄞ)),
					result  => q(chai),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄔㄨㄥ)),
					result  => q(chong1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄔㄨㄥ)),
					result  => q(chong),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄔㄨㄢ)),
					result  => q(chuan1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄔㄨㄢ)),
					result  => q(chuan),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄔㄨㄞ)),
					result  => q(chuai1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄔㄨㄞ)),
					result  => q(chuai),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄔㄥ)),
					result  => q(cheng1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄔㄥ)),
					result  => q(cheng),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄔㄤ)),
					result  => q(chang1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄔㄤ)),
					result  => q(chang),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄔㄨㄤ)),
					result  => q(chuang1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄔㄨㄤ)),
					result  => q(chuang),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄓ)),
					result  => q(zhi1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄓ)),
					result  => q(zhi),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄓㄨ)),
					result  => q(zhu1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄓㄨ)),
					result  => q(zhu),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄓㄜ)),
					result  => q(zhe1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄓㄜ)),
					result  => q(zhe),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄓㄚ)),
					result  => q(zha1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄓㄚ)),
					result  => q(zha),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄓㄨㄣ)),
					result  => q(zhun1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄓㄨㄣ)),
					result  => q(zhun),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄓㄨㄟ)),
					result  => q(zhui1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄓㄨㄟ)),
					result  => q(zhui),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄓㄨㄛ)),
					result  => q(zhuo1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄓㄨㄛ)),
					result  => q(zhuo),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄓㄨㄚ)),
					result  => q(zhua1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄓㄨㄚ)),
					result  => q(zhua),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄓㄣ)),
					result  => q(zhen1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄓㄣ)),
					result  => q(zhen),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄓㄢ)),
					result  => q(zhan1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄓㄢ)),
					result  => q(zhan),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄓㄡ)),
					result  => q(zhou1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄓㄡ)),
					result  => q(zhou),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄓㄠ)),
					result  => q(zhao1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄓㄠ)),
					result  => q(zhao),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄓㄟ)),
					result  => q(zhei1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄓㄟ)),
					result  => q(zhei),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄓㄞ)),
					result  => q(zhai1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄓㄞ)),
					result  => q(zhai),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄓㄨㄥ)),
					result  => q(zhong1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄓㄨㄥ)),
					result  => q(zhong),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄓㄨㄢ)),
					result  => q(zhuan1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄓㄨㄢ)),
					result  => q(zhuan),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄓㄨㄞ)),
					result  => q(zhuai1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄓㄨㄞ)),
					result  => q(zhuai),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄓㄥ)),
					result  => q(zheng1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄓㄥ)),
					result  => q(zheng),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄓㄤ)),
					result  => q(zhang1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄓㄤ)),
					result  => q(zhang),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄓㄨㄤ)),
					result  => q(zhuang1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄓㄨㄤ)),
					result  => q(zhuang),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄒㄩ)),
					result  => q(xu1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄒㄩ)),
					result  => q(xu),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄒㄧ)),
					result  => q(xi1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄒㄧ)),
					result  => q(xi),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄒㄩㄣ)),
					result  => q(xun1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄒㄩㄣ)),
					result  => q(xun),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄒㄩㄝ)),
					result  => q(xue1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄒㄩㄝ)),
					result  => q(xue),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄒㄧㄣ)),
					result  => q(xin1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄒㄧㄣ)),
					result  => q(xin),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄒㄧㄡ)),
					result  => q(xiu1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄒㄧㄡ)),
					result  => q(xiu),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄒㄧㄝ)),
					result  => q(xie1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄒㄧㄝ)),
					result  => q(xie),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄒㄧㄚ)),
					result  => q(xia1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄒㄧㄚ)),
					result  => q(xia),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄒㄩㄢ)),
					result  => q(xuan1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄒㄩㄢ)),
					result  => q(xuan),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄒㄧㄥ)),
					result  => q(xing1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄒㄧㄥ)),
					result  => q(xing),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄒㄧㄢ)),
					result  => q(xian1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄒㄧㄢ)),
					result  => q(xian),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄒㄧㄠ)),
					result  => q(xiao1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄒㄧㄠ)),
					result  => q(xiao),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄒㄩㄥ)),
					result  => q(xiong1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄒㄩㄥ)),
					result  => q(xiong),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄒㄧㄤ)),
					result  => q(xiang1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄒㄧㄤ)),
					result  => q(xiang),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄑㄩ)),
					result  => q(qu1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄑㄩ)),
					result  => q(qu),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄑㄧ)),
					result  => q(qi1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄑㄧ)),
					result  => q(qi),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄑㄩㄣ)),
					result  => q(qun1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄑㄩㄣ)),
					result  => q(qun),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄑㄩㄝ)),
					result  => q(que1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄑㄩㄝ)),
					result  => q(que),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄑㄧㄣ)),
					result  => q(qin1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄑㄧㄣ)),
					result  => q(qin),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄑㄧㄡ)),
					result  => q(qiu1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄑㄧㄡ)),
					result  => q(qiu),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄑㄧㄝ)),
					result  => q(qie1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄑㄧㄝ)),
					result  => q(qie),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄑㄧㄚ)),
					result  => q(qia1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄑㄧㄚ)),
					result  => q(qia),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄑㄩㄢ)),
					result  => q(quan1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄑㄩㄢ)),
					result  => q(quan),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄑㄧㄥ)),
					result  => q(qing1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄑㄧㄥ)),
					result  => q(qing),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄑㄧㄢ)),
					result  => q(qian1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄑㄧㄢ)),
					result  => q(qian),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄑㄧㄠ)),
					result  => q(qiao1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄑㄧㄠ)),
					result  => q(qiao),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄑㄩㄥ)),
					result  => q(qiong1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄑㄩㄥ)),
					result  => q(qiong),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄑㄧㄤ)),
					result  => q(qiang1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄑㄧㄤ)),
					result  => q(qiang),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄐㄩ)),
					result  => q(ju1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄐㄩ)),
					result  => q(ju),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄐㄧ)),
					result  => q(ji1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄐㄧ)),
					result  => q(ji),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄐㄩㄣ)),
					result  => q(jun1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄐㄩㄣ)),
					result  => q(jun),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄐㄩㄝ)),
					result  => q(jue1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄐㄩㄝ)),
					result  => q(jue),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄐㄧㄣ)),
					result  => q(jin1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄐㄧㄣ)),
					result  => q(jin),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄐㄧㄡ)),
					result  => q(jiu1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄐㄧㄡ)),
					result  => q(jiu),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄐㄧㄝ)),
					result  => q(jie1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄐㄧㄝ)),
					result  => q(jie),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄐㄧㄚ)),
					result  => q(jia1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄐㄧㄚ)),
					result  => q(jia),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄐㄩㄢ)),
					result  => q(juan1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄐㄩㄢ)),
					result  => q(juan),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄐㄧㄥ)),
					result  => q(jing1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄐㄧㄥ)),
					result  => q(jing),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄐㄧㄢ)),
					result  => q(jian1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄐㄧㄢ)),
					result  => q(jian),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄐㄧㄠ)),
					result  => q(jiao1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄐㄧㄠ)),
					result  => q(jiao),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄐㄩㄥ)),
					result  => q(jiong1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄐㄩㄥ)),
					result  => q(jiong),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄐㄧㄤ)),
					result  => q(jiang1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄐㄧㄤ)),
					result  => q(jiang),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄏㄨ)),
					result  => q(hu1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄏㄨ)),
					result  => q(hu),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄏㄜ)),
					result  => q(he1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄏㄜ)),
					result  => q(he),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄏㄛ)),
					result  => q(ho1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄏㄛ)),
					result  => q(ho),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄏㄚ)),
					result  => q(ha1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄏㄚ)),
					result  => q(ha),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄏㄇ)),
					result  => q(hm1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄏㄇ)),
					result  => q(hm),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄏㄨㄣ)),
					result  => q(hun1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄏㄨㄣ)),
					result  => q(hun),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄏㄨㄟ)),
					result  => q(hui1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄏㄨㄟ)),
					result  => q(hui),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄏㄨㄛ)),
					result  => q(huo1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄏㄨㄛ)),
					result  => q(huo),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄏㄨㄚ)),
					result  => q(hua1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄏㄨㄚ)),
					result  => q(hua),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄏㄣ)),
					result  => q(hen1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄏㄣ)),
					result  => q(hen),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄏㄢ)),
					result  => q(han1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄏㄢ)),
					result  => q(han),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄏㄡ)),
					result  => q(hou1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄏㄡ)),
					result  => q(hou),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄏㄠ)),
					result  => q(hao1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄏㄠ)),
					result  => q(hao),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄏㄟ)),
					result  => q(hei1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄏㄟ)),
					result  => q(hei),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄏㄞ)),
					result  => q(hai1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄏㄞ)),
					result  => q(hai),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄏㄨㄥ)),
					result  => q(hong1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄏㄨㄥ)),
					result  => q(hong),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄏㄨㄢ)),
					result  => q(huan1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄏㄨㄢ)),
					result  => q(huan),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄏㄨㄞ)),
					result  => q(huai1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄏㄨㄞ)),
					result  => q(huai),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄏㄥ)),
					result  => q(heng1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄏㄥ)),
					result  => q(heng),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄏㄤ)),
					result  => q(hang1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄏㄤ)),
					result  => q(hang),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄏㄨㄤ)),
					result  => q(huang1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄏㄨㄤ)),
					result  => q(huang),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄎㄨ)),
					result  => q(ku1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄎㄨ)),
					result  => q(ku),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄎㄜ)),
					result  => q(ke1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄎㄜ)),
					result  => q(ke),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄎㄚ)),
					result  => q(ka1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄎㄚ)),
					result  => q(ka),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄎㄨㄣ)),
					result  => q(kun1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄎㄨㄣ)),
					result  => q(kun),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄎㄨㄟ)),
					result  => q(kui1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄎㄨㄟ)),
					result  => q(kui),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄎㄨㄛ)),
					result  => q(kuo1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄎㄨㄛ)),
					result  => q(kuo),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄎㄨㄚ)),
					result  => q(kua1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄎㄨㄚ)),
					result  => q(kua),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄎㄣ)),
					result  => q(ken1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄎㄣ)),
					result  => q(ken),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄎㄢ)),
					result  => q(kan1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄎㄢ)),
					result  => q(kan),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄎㄡ)),
					result  => q(kou1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄎㄡ)),
					result  => q(kou),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄎㄠ)),
					result  => q(kao1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄎㄠ)),
					result  => q(kao),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄎㄞ)),
					result  => q(kai1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄎㄞ)),
					result  => q(kai),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄎㄨㄥ)),
					result  => q(kong1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄎㄨㄥ)),
					result  => q(kong),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄎㄨㄢ)),
					result  => q(kuan1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄎㄨㄢ)),
					result  => q(kuan),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄎㄨㄞ)),
					result  => q(kuai1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄎㄨㄞ)),
					result  => q(kuai),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄎㄥ)),
					result  => q(keng1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄎㄥ)),
					result  => q(keng),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄎㄤ)),
					result  => q(kang1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄎㄤ)),
					result  => q(kang),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄎㄨㄤ)),
					result  => q(kuang1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄎㄨㄤ)),
					result  => q(kuang),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄍㄨ)),
					result  => q(gu1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄍㄨ)),
					result  => q(gu),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄍㄧ)),
					result  => q(gi1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄍㄧ)),
					result  => q(gi),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄍㄜ)),
					result  => q(ge1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄍㄜ)),
					result  => q(ge),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄍㄚ)),
					result  => q(ga1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄍㄚ)),
					result  => q(ga),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄍㄨㄣ)),
					result  => q(gun1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄍㄨㄣ)),
					result  => q(gun),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄍㄨㄟ)),
					result  => q(gui1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄍㄨㄟ)),
					result  => q(gui),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄍㄨㄛ)),
					result  => q(guo1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄍㄨㄛ)),
					result  => q(guo),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄍㄨㄚ)),
					result  => q(gua1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄍㄨㄚ)),
					result  => q(gua),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄍㄣ)),
					result  => q(gen1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄍㄣ)),
					result  => q(gen),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄍㄢ)),
					result  => q(gan1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄍㄢ)),
					result  => q(gan),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄍㄡ)),
					result  => q(gou1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄍㄡ)),
					result  => q(gou),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄍㄠ)),
					result  => q(gao1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄍㄠ)),
					result  => q(gao),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄍㄟ)),
					result  => q(gei1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄍㄟ)),
					result  => q(gei),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄍㄞ)),
					result  => q(gai1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄍㄞ)),
					result  => q(gai),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄍㄨㄥ)),
					result  => q(gong1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄍㄨㄥ)),
					result  => q(gong),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄍㄨㄢ)),
					result  => q(guan1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄍㄨㄢ)),
					result  => q(guan),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄍㄨㄞ)),
					result  => q(guai1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄍㄨㄞ)),
					result  => q(guai),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄍㄥ)),
					result  => q(geng1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄍㄥ)),
					result  => q(geng),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄍㄤ)),
					result  => q(gang1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄍㄤ)),
					result  => q(gang),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄍㄨㄤ)),
					result  => q(guang1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄍㄨㄤ)),
					result  => q(guang),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄌㄩ)),
					result  => q(lü1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄌㄩ)),
					result  => q(lü),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄌㄨ)),
					result  => q(lu1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄌㄨ)),
					result  => q(lu),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄌㄧ)),
					result  => q(li1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄌㄧ)),
					result  => q(li),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄌㄜ)),
					result  => q(le1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄌㄜ)),
					result  => q(le),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄌㄛ)),
					result  => q(lo1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄌㄛ)),
					result  => q(lo),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄌㄚ)),
					result  => q(la1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄌㄚ)),
					result  => q(la),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄌㄩㄝ)),
					result  => q(lüe1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄌㄩㄝ)),
					result  => q(lüe),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄌㄨㄣ)),
					result  => q(lun1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄌㄨㄣ)),
					result  => q(lun),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄌㄨㄛ)),
					result  => q(luo1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄌㄨㄛ)),
					result  => q(luo),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄌㄧㄣ)),
					result  => q(lin1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄌㄧㄣ)),
					result  => q(lin),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄌㄧㄡ)),
					result  => q(liu1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄌㄧㄡ)),
					result  => q(liu),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄌㄧㄝ)),
					result  => q(lie1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄌㄧㄝ)),
					result  => q(lie),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄌㄧㄚ)),
					result  => q(lia1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄌㄧㄚ)),
					result  => q(lia),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄌㄢ)),
					result  => q(lan1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄌㄢ)),
					result  => q(lan),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄌㄡ)),
					result  => q(lou1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄌㄡ)),
					result  => q(lou),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄌㄠ)),
					result  => q(lao1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄌㄠ)),
					result  => q(lao),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄌㄟ)),
					result  => q(lei1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄌㄟ)),
					result  => q(lei),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄌㄞ)),
					result  => q(lai1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄌㄞ)),
					result  => q(lai),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄌㄩㄢ)),
					result  => q(lüan1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄌㄩㄢ)),
					result  => q(lüan),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄌㄨㄥ)),
					result  => q(long1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄌㄨㄥ)),
					result  => q(long),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄌㄨㄢ)),
					result  => q(luan1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄌㄨㄢ)),
					result  => q(luan),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄌㄧㄥ)),
					result  => q(ling1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄌㄧㄥ)),
					result  => q(ling),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄌㄧㄢ)),
					result  => q(lian1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄌㄧㄢ)),
					result  => q(lian),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄌㄧㄠ)),
					result  => q(liao1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄌㄧㄠ)),
					result  => q(liao),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄌㄥ)),
					result  => q(leng1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄌㄥ)),
					result  => q(leng),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄌㄤ)),
					result  => q(lang1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄌㄤ)),
					result  => q(lang),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄌㄧㄤ)),
					result  => q(liang1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄌㄧㄤ)),
					result  => q(liang),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄋㄩ)),
					result  => q(nü1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄋㄩ)),
					result  => q(nü),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄋㄨ)),
					result  => q(nu1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄋㄨ)),
					result  => q(nu),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄋㄧ)),
					result  => q(ni1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄋㄧ)),
					result  => q(ni),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄋㄜ)),
					result  => q(ne1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄋㄜ)),
					result  => q(ne),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄋㄚ)),
					result  => q(na1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄋㄚ)),
					result  => q(na),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄋㄩㄝ)),
					result  => q(nüe1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄋㄩㄝ)),
					result  => q(nüe),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄋㄨㄣ)),
					result  => q(nun1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄋㄨㄣ)),
					result  => q(nun),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄋㄨㄛ)),
					result  => q(nuo1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄋㄨㄛ)),
					result  => q(nuo),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄋㄧㄣ)),
					result  => q(nin1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄋㄧㄣ)),
					result  => q(nin),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄋㄧㄡ)),
					result  => q(niu1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄋㄧㄡ)),
					result  => q(niu),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄋㄧㄝ)),
					result  => q(nie1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄋㄧㄝ)),
					result  => q(nie),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄋㄧㄚ)),
					result  => q(nia1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄋㄧㄚ)),
					result  => q(nia),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄋㄣ)),
					result  => q(nen1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄋㄣ)),
					result  => q(nen),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄋㄢ)),
					result  => q(nan1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄋㄢ)),
					result  => q(nan),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄋㄡ)),
					result  => q(nou1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄋㄡ)),
					result  => q(nou),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄋㄠ)),
					result  => q(nao1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄋㄠ)),
					result  => q(nao),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄋㄟ)),
					result  => q(nei1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄋㄟ)),
					result  => q(nei),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄋㄞ)),
					result  => q(nai1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄋㄞ)),
					result  => q(nai),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄋㄨㄥ)),
					result  => q(nong1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄋㄨㄥ)),
					result  => q(nong),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄋㄨㄢ)),
					result  => q(nuan1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄋㄨㄢ)),
					result  => q(nuan),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄋㄧㄥ)),
					result  => q(ning1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄋㄧㄥ)),
					result  => q(ning),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄋㄧㄢ)),
					result  => q(nian1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄋㄧㄢ)),
					result  => q(nian),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄋㄧㄠ)),
					result  => q(niao1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄋㄧㄠ)),
					result  => q(niao),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄋㄥ)),
					result  => q(neng1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄋㄥ)),
					result  => q(neng),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄋㄤ)),
					result  => q(nang1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄋㄤ)),
					result  => q(nang),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄋㄧㄤ)),
					result  => q(niang1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄋㄧㄤ)),
					result  => q(niang),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄊㄨ)),
					result  => q(tu1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄊㄨ)),
					result  => q(tu),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄊㄧ)),
					result  => q(ti1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄊㄧ)),
					result  => q(ti),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄊㄜ)),
					result  => q(te1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄊㄜ)),
					result  => q(te),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄊㄚ)),
					result  => q(ta1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄊㄚ)),
					result  => q(ta),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄊㄨㄣ)),
					result  => q(tun1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄊㄨㄣ)),
					result  => q(tun),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄊㄨㄟ)),
					result  => q(tui1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄊㄨㄟ)),
					result  => q(tui),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄊㄨㄛ)),
					result  => q(tuo1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄊㄨㄛ)),
					result  => q(tuo),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄊㄧㄝ)),
					result  => q(tie1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄊㄧㄝ)),
					result  => q(tie),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄊㄢ)),
					result  => q(tan1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄊㄢ)),
					result  => q(tan),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄊㄡ)),
					result  => q(tou1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄊㄡ)),
					result  => q(tou),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄊㄠ)),
					result  => q(tao1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄊㄠ)),
					result  => q(tao),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄊㄞ)),
					result  => q(tai1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄊㄞ)),
					result  => q(tai),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄊㄨㄥ)),
					result  => q(tong1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄊㄨㄥ)),
					result  => q(tong),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄊㄨㄢ)),
					result  => q(tuan1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄊㄨㄢ)),
					result  => q(tuan),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄊㄧㄥ)),
					result  => q(ting1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄊㄧㄥ)),
					result  => q(ting),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄊㄧㄢ)),
					result  => q(tian1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄊㄧㄢ)),
					result  => q(tian),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄊㄧㄠ)),
					result  => q(tiao1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄊㄧㄠ)),
					result  => q(tiao),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄊㄥ)),
					result  => q(teng1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄊㄥ)),
					result  => q(teng),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄊㄤ)),
					result  => q(tang1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄊㄤ)),
					result  => q(tang),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄉㄨ)),
					result  => q(du1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄉㄨ)),
					result  => q(du),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄉㄧ)),
					result  => q(di1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄉㄧ)),
					result  => q(di),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄉㄜ)),
					result  => q(de1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄉㄜ)),
					result  => q(de),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄉㄚ)),
					result  => q(da1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄉㄚ)),
					result  => q(da),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄉㄨㄣ)),
					result  => q(dun1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄉㄨㄣ)),
					result  => q(dun),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄉㄨㄟ)),
					result  => q(dui1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄉㄨㄟ)),
					result  => q(dui),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄉㄨㄛ)),
					result  => q(duo1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄉㄨㄛ)),
					result  => q(duo),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄉㄧㄣ)),
					result  => q(din1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄉㄧㄣ)),
					result  => q(din),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄉㄧㄡ)),
					result  => q(diu1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄉㄧㄡ)),
					result  => q(diu),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄉㄧㄝ)),
					result  => q(die1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄉㄧㄝ)),
					result  => q(die),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄉㄧㄚ)),
					result  => q(dia1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄉㄧㄚ)),
					result  => q(dia),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄉㄣ)),
					result  => q(den1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄉㄣ)),
					result  => q(den),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄉㄢ)),
					result  => q(dan1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄉㄢ)),
					result  => q(dan),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄉㄡ)),
					result  => q(dou1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄉㄡ)),
					result  => q(dou),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄉㄠ)),
					result  => q(dao1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄉㄠ)),
					result  => q(dao),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄉㄟ)),
					result  => q(dei1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄉㄟ)),
					result  => q(dei),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄉㄞ)),
					result  => q(dai1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄉㄞ)),
					result  => q(dai),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄉㄨㄥ)),
					result  => q(dong1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄉㄨㄥ)),
					result  => q(dong),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄉㄨㄢ)),
					result  => q(duan1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄉㄨㄢ)),
					result  => q(duan),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄉㄧㄥ)),
					result  => q(ding1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄉㄧㄥ)),
					result  => q(ding),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄉㄧㄢ)),
					result  => q(dian1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄉㄧㄢ)),
					result  => q(dian),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄉㄧㄠ)),
					result  => q(diao1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄉㄧㄠ)),
					result  => q(diao),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄉㄥ)),
					result  => q(deng1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄉㄥ)),
					result  => q(deng),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄉㄤ)),
					result  => q(dang1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄉㄤ)),
					result  => q(dang),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄉㄧㄤ)),
					result  => q(diang1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄉㄧㄤ)),
					result  => q(diang),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄈㄨ)),
					result  => q(fu1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄈㄨ)),
					result  => q(fu),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄈㄛ)),
					result  => q(fo1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄈㄛ)),
					result  => q(fo),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄈㄚ)),
					result  => q(fa1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄈㄚ)),
					result  => q(fa),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄈㄣ)),
					result  => q(fen1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄈㄣ)),
					result  => q(fen),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄈㄢ)),
					result  => q(fan1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄈㄢ)),
					result  => q(fan),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄈㄡ)),
					result  => q(fou1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄈㄡ)),
					result  => q(fou),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄈㄟ)),
					result  => q(fei1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄈㄟ)),
					result  => q(fei),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄈㄧㄠ)),
					result  => q(fiao1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄈㄧㄠ)),
					result  => q(fiao),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄈㄥ)),
					result  => q(feng1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄈㄥ)),
					result  => q(feng),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄈㄤ)),
					result  => q(fang1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄈㄤ)),
					result  => q(fang),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄇㄨ)),
					result  => q(mu1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄇㄨ)),
					result  => q(mu),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄇㄧ)),
					result  => q(mi1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄇㄧ)),
					result  => q(mi),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄇㄜ)),
					result  => q(me1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄇㄜ)),
					result  => q(me),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄇㄛ)),
					result  => q(mo1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄇㄛ)),
					result  => q(mo),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄇㄚ)),
					result  => q(ma1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄇㄚ)),
					result  => q(ma),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄇㄧㄣ)),
					result  => q(min1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄇㄧㄣ)),
					result  => q(min),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄇㄧㄡ)),
					result  => q(miu1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄇㄧㄡ)),
					result  => q(miu),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄇㄧㄝ)),
					result  => q(mie1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄇㄧㄝ)),
					result  => q(mie),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄇㄣ)),
					result  => q(men1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄇㄣ)),
					result  => q(men),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄇㄢ)),
					result  => q(man1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄇㄢ)),
					result  => q(man),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄇㄡ)),
					result  => q(mou1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄇㄡ)),
					result  => q(mou),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄇㄠ)),
					result  => q(mao1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄇㄠ)),
					result  => q(mao),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄇㄟ)),
					result  => q(mei1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄇㄟ)),
					result  => q(mei),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄇㄞ)),
					result  => q(mai1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄇㄞ)),
					result  => q(mai),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄇㄧㄥ)),
					result  => q(ming1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄇㄧㄥ)),
					result  => q(ming),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄇㄧㄢ)),
					result  => q(mian1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄇㄧㄢ)),
					result  => q(mian),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄇㄧㄠ)),
					result  => q(miao1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄇㄧㄠ)),
					result  => q(miao),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄇㄥ)),
					result  => q(meng1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄇㄥ)),
					result  => q(meng),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄇㄤ)),
					result  => q(mang1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄇㄤ)),
					result  => q(mang),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄆㄨ)),
					result  => q(pu1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄆㄨ)),
					result  => q(pu),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄆㄧ)),
					result  => q(pi1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄆㄧ)),
					result  => q(pi),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄆㄛ)),
					result  => q(po1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄆㄛ)),
					result  => q(po),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄆㄚ)),
					result  => q(pa1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄆㄚ)),
					result  => q(pa),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄆㄧㄣ)),
					result  => q(pin1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄆㄧㄣ)),
					result  => q(pin),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄆㄧㄝ)),
					result  => q(pie1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄆㄧㄝ)),
					result  => q(pie),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄆㄣ)),
					result  => q(pen1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄆㄣ)),
					result  => q(pen),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄆㄢ)),
					result  => q(pan1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄆㄢ)),
					result  => q(pan),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄆㄡ)),
					result  => q(pou1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄆㄡ)),
					result  => q(pou),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄆㄠ)),
					result  => q(pao1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄆㄠ)),
					result  => q(pao),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄆㄟ)),
					result  => q(pei1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄆㄟ)),
					result  => q(pei),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄆㄞ)),
					result  => q(pai1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄆㄞ)),
					result  => q(pai),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄆㄧㄥ)),
					result  => q(ping1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄆㄧㄥ)),
					result  => q(ping),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄆㄧㄢ)),
					result  => q(pian1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄆㄧㄢ)),
					result  => q(pian),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄆㄧㄠ)),
					result  => q(piao1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄆㄧㄠ)),
					result  => q(piao),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄆㄥ)),
					result  => q(peng1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄆㄥ)),
					result  => q(peng),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄆㄤ)),
					result  => q(pang1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄆㄤ)),
					result  => q(pang),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄅㄨ)),
					result  => q(bu1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄅㄨ)),
					result  => q(bu),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄅㄧ)),
					result  => q(bi1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄅㄧ)),
					result  => q(bi),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄅㄛ)),
					result  => q(bo1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄅㄛ)),
					result  => q(bo),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄅㄚ)),
					result  => q(ba1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄅㄚ)),
					result  => q(ba),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄅㄨㄣ)),
					result  => q(bun1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄅㄨㄣ)),
					result  => q(bun),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄅㄧㄣ)),
					result  => q(bin1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄅㄧㄣ)),
					result  => q(bin),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄅㄧㄝ)),
					result  => q(bie1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄅㄧㄝ)),
					result  => q(bie),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄅㄣ)),
					result  => q(ben1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄅㄣ)),
					result  => q(ben),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄅㄢ)),
					result  => q(ban1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄅㄢ)),
					result  => q(ban),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄅㄠ)),
					result  => q(bao1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄅㄠ)),
					result  => q(bao),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄅㄟ)),
					result  => q(bei1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄅㄟ)),
					result  => q(bei),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄅㄞ)),
					result  => q(bai1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄅㄞ)),
					result  => q(bai),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄅㄧㄥ)),
					result  => q(bing1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄅㄧㄥ)),
					result  => q(bing),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄅㄧㄢ)),
					result  => q(bian1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄅㄧㄢ)),
					result  => q(bian),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄅㄧㄠ)),
					result  => q(biao1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄅㄧㄠ)),
					result  => q(biao),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄅㄥ)),
					result  => q(beng1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄅㄥ)),
					result  => q(beng),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ㄅㄤ)),
					result  => q(bang1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ˉˊˇˋ˙])),
					replace => q((?^u:ㄅㄤ)),
					result  => q(bang),
					revisit => 0,
				},
			],
		},
		{
			type => 'transform',
			data => [
				{
					from => q(NumericPinyin),
					to => q(Latin),
				},
			]
		},
	] },
);

no Moose;
__PACKAGE__->meta->make_immutable;

1;

# vim: tabstop=4
